package envoy.client.ui;

import java.awt.Component;
import java.text.SimpleDateFormat;

import javax.swing.JLabel;

import envoy.client.Settings;
import envoy.client.ui.list.ComponentList;
import envoy.client.ui.list.ComponentListCellRenderer;
import envoy.data.Message;

/**
 * Defines how a message is displayed.<br>
 * <br>
 * Project: <strong>envoy-client</strong><br>
 * File: <strong>UserListRenderer.java</strong><br>
 * Created: <strong>19 Oct 2019</strong><br>
 *
 * @author Kai S. K. Engelbart
 * @author Maximilian K&auml;fer
 * @since Envoy v0.1-alpha
 */
public class MessageListRenderer extends JLabel implements ComponentListCellRenderer<Message> {

	private static final long serialVersionUID = 5164417379767181198L;

	@Override
	public Component getListCellComponent(ComponentList<? extends Message> list, Message value, boolean isSelected) {
		if (isSelected) {
			setBackground(Color.DARK_GRAY);
			setForeground(Color.RED);
//			setBackground(list.getSelectionBackground());
//			setForeground(list.getSelectionForeground());
		} else {
			setBackground(list.getBackground());
			setForeground(list.getForeground());
		}

		setOpaque(true);

		// TODO: Handle message attachments

		final String	text	= value.getText();
		final String	state	= value.getStatus().toString();
		final String	date	= new SimpleDateFormat("dd.MM.yyyy HH.mm").format(value.getCreationDate());

		// Getting the MessageColor in the Chat of the current theme
		String textColor = Settings.getInstance().getThemes().get(Settings.getInstance().getCurrentTheme()).getMessageColorChat().toHex();

		// Getting the DateColor in the Chat of the current theme
		String dateColor = Settings.getInstance().getThemes().get(Settings.getInstance().getCurrentTheme()).getDateColorChat().toHex();

		setText(String.format("<html><p style=\"color:%s\"><b><small>%s</b></small><br><p style=\"color:%s\">%s :%s</html>",
				dateColor,
				date,
				textColor,
				text,
				state));
		return this;
	}
}